Source Code
===========

The source code is available from
`GitHub <https://github.com/spatial-model-editor/spatial-model-editor>`_,
where `Bug reports <https://github.com/spatial-model-editor/spatial-model-editor/issues/new?assignees=&labels=&template=bug_report.md&title=>`_
and `Feature requests <https://github.com/spatial-model-editor/spatial-model-editor/issues/new?assignees=&labels=&template=feature_request.md&title=>`_
are very welcome.

The `spatial-model-editor <https://github.com/spatial-model-editor>`_
organization on GitHub contains more repositories including the
source code for the website,
`spatial-model-editor.github.io <https://spatial-model-editor.github.io>`_,
the continuous deployment scripts, and other related components.
